@@ -25,9 +25,9 @@ def _get_scp_name(scp_id: int):
     if scp_id < 1000:
       url = 'http://www.scp-wiki.net/scp-series'
     elif scp_id % 1000 == 0:
-      url = f'http://www.scp-wiki.net/scp-series-{scp_id/1000}'
+      url = f'http://www.scp-wiki.net/scp-series-{scp_id/1000+1}'
     else:
-      url = f'http://www.scp-wiki.net/scp-series-{ceil(scp_id/1000, 0)}'
+      url = f'http://www.scp-wiki.net/scp-series-{ceil(scp_id/1000)}'
 
     # Grab the HTML and parse as needed.
     r = urllib.request.urlopen(url=url)
@@ -37,9 +37,10 @@ def _get_scp_name(scp_id: int):
       list_elements = content.find_all('li')
 
       for li in list_elements:
-        if re.findall('[0-9]+', li.next['href']):
-          if int(re.findall('[0-9]+', li.next['href'])[0]) == scp_id:
-            return re.split(' - ', li.get_text())[-1]
+        if re.findall('[0-9]+', li.find_next('a')['href']):
+          if int(re.findall('[0-9]+', li.find_next('a')['href'])[0]) == scp_id:
+            scp_name = re.split('-', li.get_text())[-1]
+            return scp_name.strip(' ')
     
     # Handle 404 errors.
     except urllib.error.HTTPError as e:
